==> nextcloud-jitsi-v0.16.2.tar.gz: jitsi/l10n/de.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "Konferenzen",
    "Jitsi Integration" : "Jitsi-Einbindung",
    "Conferences" : "Konferenzen",
    "Jitsi Integration (unofficial)" : "Jitsi-Einbindung (inoffiziell)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Diese App integriert Jitsi-Konferenzen in Nextcloud.\n\nMerkmale:\n- 🎥 Einfache Online-Konferenzen in Nextcloud mit Jitsi\n- 🔗 Links zu gemeinsam nutzbaren Konferenzräumen\n- 🔎 Zeigt Konferenzräume in der globalen Suche an\n- ✅ Systemtest vor dem Beitritt zu einer Konferenz\n\nBitte lese die [Dokumentation] (https://github.com/nextcloud/jitsi).",
    "Loading …" : "Lade …",
    "Server URL (required)" : "Server-URL (wird benötigt)",
    "Help link (optional)" : "Hilfe-Link (optional)",
    "Display \"Join using the Jitsi app\"" : "„Mit der Jitsi-App beitreten“ anzeigen",
    "JWT Secret (optional)" : "JWT-Secret (optional)",
    "JWT App ID" : "JWT App-ID",
    "JWT Audience (optional)" : "JWT-Zielgruppe (optional)",
    "JWT Issuer (optional)" : "JWT-Aussteller (optional)",
    "save" : "Speichern",
    "saved" : "Gespeichert",
    "Saving …" : "Speichern …",
    "Please provide a Jitsi instance URL" : "Bitte gib eine Jitsi-Instanz-URL an",
    "The server URL must start with https://" : "Die Server-URL muss mit https:// beginnen",
    "It is highly recommended to set up a dedicated Jitsi instance" : "Es wird dringend empfohlen, eine dedizierte Jitsi-Instanz einzurichten",
    "Please provide the App ID" : "Bitte gib die App ID  an",
    "Failed to save settings" : "Einstellungen konnten nicht gespeichert werden",
    "Failed to load settings" : "Einstellungen konnten nicht geladen werden",
    "Conference rooms" : "Konferenz-Räume",
    "Conference" : "Konferenz",
    "Conference left" : "Konferenz verlassen",
    "Problems detected" : "Probleme gefunden",
    "Your browser is non-optimal:" : "Dein Browser ist nicht optimal:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Die Audio- und Videoqualität kann schlecht sein. Es wird empfohlen, eine aktuelle Version von <b>Firefox/Chrome/Chromium</b> zu verwenden.",
    "Browser not supported" : "Browser wird nicht unterstützt",
    "Show system check" : "Systemcheck anzeigen",
    "Your name:" : "Dein Name:",
    "Click here to join" : "Zum Beitreten hier klicken",
    "Start muted" : "Stumm geschaltet starten",
    "Start with camera off" : "Mit ausgeschalteter Kamera starten",
    "Join with desktop app" : "Mit der Desktop-App teilnehmen",
    "Join with mobile app" : "Mit der Smartphone-App teilnehmen",
    "App button not working?" : "Funktioniert der App-Button nicht?",
    "Download the desktop app here ↗" : "Lade die Desktop-App hier herunter ↗",
    "The mobile app is available via the app store of your choice." : "Die Smartphone-App ist über den App Store deiner Wahl erhältlich.",
    "After successful installation try the button again." : "Nach erfolgreicher Installation versuche erneut den Button zu drücken.",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "Funktioniert immer noch nicht? Kopiere den unten stehenden Link und füge ihn in das Eingabefeld auf dem Startbildschirm der Jitsi App ein.",
    "Link copied" : "Link kopiert",
    "Cannot copy, please copy the link manually" : "Kopieren fehlgeschlagen. Bitte kopiere den Link manuell",
    "Copy to clipboard" : "In die Zwischenablage kopieren",
    "Browser" : "Browser",
    "non-optimal" : "Nicht optimal",
    "not supported" : "Nicht unterstützt",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Die Audio- und Videoqualität kann schlecht sein. <br> Es wird empfohlen, eine aktuelle Version von <b>Firefox/Chrome/Chromium</b> zu verwenden.",
    "Help" : "Hilfe",
    "Camera" : "Kamera",
    "Name of the new room" : "Name des neuen Raums",
    "No conference rooms yet" : "Noch keine Konferenzräume",
    "Create the first room:" : "Erstelle den ersten Raum:",
    "Microphone" : "Mikrofon",
    "Join" : "Beitreten",
    "Delete room" : "Raum löschen",
    "Room not found" : "Raum nicht gefunden",
    "Please check the link/URL and ask your host" : "Bitte überprüfe den Link/URL und frage deinen Gastgeber",
    "Audio output" : "Audio-Ausgabe",
    "Play test sound" : "Testton abspielen",
    "System check" : "Systemcheck",
    "Got issues?" : "Hast du ein Problem?",
    "Known problems / what you can try" : "Bekannte Probleme / was du versuchen kannst",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Akzeptiere die Zugriffsberechtigungen für das Mikrofon/die Kamera oben auf dem Bildschirm.",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Überprüfe die Zugriffsberechtigungen für Mikrofon/Kamera, indem du auf das Symbol neben der Adressleiste klickst. Lade dann die Seite neu.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• Wenn du DroidCam verwendest: Verbinde dich mit der mobilen Kamera und lade dann die Seite neu",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Versuche, mit der Jitsi-App beizutreten (folgen Sie den Anweisungen unten auf der Seite).",
    "No camera/microphone access" : "Kein Zugriff auf Kamera/Mikrofon",
    "Review your browser camera and microphone access settings" : "Überprüfe die Kamera- und Mikrofonzugriffseinstellungen deines Browsers",
    "Click here for {browser} instructions" : "Klicke hier, um Anweisungen für {Browser} zu erhalten",
    "Does not work?" : "Funktioniert es nicht?",
    "Click here for troubleshooting help" : "Klicke hier, um Hilfe bei der Fehlerbehebung zu erhalten",
    "Conferences app not yet configured" : "Konferenz-App noch nicht konfiguriert",
    "Please contact your administrator to set up the conferences app." : "Bitte wende dich an deinen Administrator, um die Konferenz-App einzurichten.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "Dein Browser (%1$s) ist veraltet und <br> wird nicht mehr unterstützt",
    "It is recommended to use the latest version of one of the following browsers:" : "Es wird empfohlen, die neueste Version eines der folgenden Browser zu verwenden:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-jitsi-v0.18.0.tar.gz: jitsi/l10n/de.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "Konferenzen",
    "Jitsi Integration" : "Jitsi-Einbindung",
    "Conferences" : "Konferenzen",
    "Jitsi Integration (unofficial)" : "Jitsi-Einbindung (inoffiziell)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Diese App integriert Jitsi-Konferenzen in Nextcloud.\n\nMerkmale:\n- 🎥 Einfache Online-Konferenzen in Nextcloud mit Jitsi\n- 🔗 Links zu gemeinsam nutzbaren Konferenzräumen\n- 🔎 Zeigt Konferenzräume in der globalen Suche an\n- ✅ Systemtest vor dem Beitritt zu einer Konferenz\n\nBitte lese die [Dokumentation] (https://github.com/nextcloud/jitsi).",
    "Loading …" : "Lade …",
    "Server URL (required)" : "Server-URL (wird benötigt)",
    "Help link (optional)" : "Hilfe-Link (optional)",
    "Display \"Join using the Jitsi app\"" : "„Mit der Jitsi-App beitreten“ anzeigen",
    "JWT Secret (optional)" : "JWT-Secret (optional)",
    "JWT App ID" : "JWT App-ID",
    "JWT Audience (optional)" : "JWT-Zielgruppe (optional)",
    "JWT Issuer (optional)" : "JWT-Aussteller (optional)",
    "save" : "Speichern",
    "saved" : "Gespeichert",
    "Saving …" : "Speichern …",
    "Please provide a Jitsi instance URL" : "Bitte gib eine Jitsi-Instanz-URL an",
    "The server URL must start with https://" : "Die Server-URL muss mit https:// beginnen",
    "It is highly recommended to set up a dedicated Jitsi instance" : "Es wird dringend empfohlen, eine dedizierte Jitsi-Instanz einzurichten",
    "Please provide the App ID" : "Bitte gib die App ID  an",
    "Failed to save settings" : "Einstellungen konnten nicht gespeichert werden",
    "Failed to load settings" : "Einstellungen konnten nicht geladen werden",
    "Conference rooms" : "Konferenz-Räume",
    "Conference" : "Konferenz",
    "Conference left" : "Konferenz verlassen",
    "Problems detected" : "Probleme gefunden",
    "Your browser is non-optimal:" : "Dein Browser ist nicht optimal:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Die Audio- und Videoqualität kann schlecht sein. Es wird empfohlen, eine aktuelle Version von <b>Firefox/Chrome/Chromium</b> zu verwenden.",
    "Browser not supported" : "Browser wird nicht unterstützt",
    "Show system check" : "Systemcheck anzeigen",
    "Your name:" : "Dein Name:",
    "Click here to join" : "Zum Beitreten hier klicken",
    "Start muted" : "Stumm geschaltet starten",
    "Start with camera off" : "Mit ausgeschalteter Kamera starten",
    "Join with desktop app" : "Mit der Desktop-App teilnehmen",
    "Join with mobile app" : "Mit der Smartphone-App teilnehmen",
    "App button not working?" : "Funktioniert der App-Button nicht?",
    "Download the desktop app here ↗" : "Lade die Desktop-App hier herunter ↗",
    "The mobile app is available via the app store of your choice." : "Die Smartphone-App ist über den App Store deiner Wahl erhältlich.",
    "After successful installation try the button again." : "Nach erfolgreicher Installation versuche erneut den Button zu drücken.",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "Funktioniert immer noch nicht? Kopiere den unten stehenden Link und füge ihn in das Eingabefeld auf dem Startbildschirm der Jitsi App ein.",
    "Link copied" : "Link kopiert",
    "Cannot copy, please copy the link manually" : "Kopieren fehlgeschlagen. Bitte kopiere den Link manuell",
    "Copy to clipboard" : "In die Zwischenablage kopieren",
    "Browser" : "Browser",
    "non-optimal" : "Nicht optimal",
    "not supported" : "Nicht unterstützt",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Die Audio- und Videoqualität kann schlecht sein. <br> Es wird empfohlen, eine aktuelle Version von <b>Firefox/Chrome/Chromium</b> zu verwenden.",
    "Help" : "Hilfe",
    "Camera" : "Kamera",
    "Name of the new room" : "Name des neuen Raums",
    "No conference rooms yet" : "Noch keine Konferenzräume",
    "Create the first room:" : "Erstelle den ersten Raum:",
    "Microphone" : "Mikrofon",
    "Join" : "Beitreten",
    "Delete room" : "Raum löschen",
    "Room not found" : "Raum nicht gefunden",
    "Please check the link/URL and ask your host" : "Bitte überprüfe den Link/URL und frage deinen Gastgeber",
    "Audio output" : "Audio-Ausgabe",
    "Play test sound" : "Testton abspielen",
    "System check" : "Systemcheck",
    "Got issues?" : "Hast du ein Problem?",
    "Known problems / what you can try" : "Bekannte Probleme / was du versuchen kannst",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Akzeptiere die Zugriffsberechtigungen für das Mikrofon/die Kamera oben auf dem Bildschirm.",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Überprüfe die Zugriffsberechtigungen für Mikrofon/Kamera, indem du auf das Symbol neben der Adressleiste klickst. Lade dann die Seite neu.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• Wenn du DroidCam verwendest: Verbinde dich mit der mobilen Kamera und lade dann die Seite neu",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Versuche, mit der Jitsi-App beizutreten (folge den Anweisungen unten auf der Seite).",
    "No camera/microphone access" : "Kein Zugriff auf Kamera/Mikrofon",
    "Review your browser camera and microphone access settings" : "Überprüfe die Kamera- und Mikrofonzugriffseinstellungen deines Browsers",
    "Click here for {browser} instructions" : "Klicke hier, um Anweisungen für {Browser} zu erhalten",
    "Does not work?" : "Funktioniert es nicht?",
    "Click here for troubleshooting help" : "Klicke hier, um Hilfe bei der Fehlerbehebung zu erhalten",
    "Conferences app not yet configured" : "Konferenz-App noch nicht konfiguriert",
    "Please contact your administrator to set up the conferences app." : "Bitte wende dich an deinen Administrator, um die Konferenz-App einzurichten.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "Dein Browser (%1$s) ist veraltet und <br> wird nicht mehr unterstützt",
    "It is recommended to use the latest version of one of the following browsers:" : "Es wird empfohlen, die neueste Version eines der folgenden Browser zu verwenden:"
},
"nplurals=2; plural=(n != 1);");
